#include "../Headers/io.h"

#include <avr/io.h>

// Function to initialize the I/O pins
void IoInit(void)
{
    // Six LEDs on the PA[0..5] -> these should be configured as outputs
    DDRA =  (1 << PA0) | (1 << PA1) | (1 << PA2) | (1 << PA3) | (1 << PA4) | (1 << PA5);
    PORTA = 0;

    // Five LEDs on the PB[0..4] -> these should be configured as outputs
    DDRB =  (1 << PB0) | (1 << PB1) | (1 << PB2) | (1 << PB3) | (1 << PB4);
    PORTB = 0;

    // 1 LED on the PORTC[0]
    DDRC =  (1 << PC0);
    PORTC = 0;

    // All pins of PORTD should be configured as inputs, pull-up resistors on PD[2:3]
    DDRD =  0;
    PORTD = (1 << PD2) | (1 << PD3);
}

// Function to update the state of LEDs according to the elapsed time
// I/O output: Overwriting the LED outputs
// time: time to be displayed in seconds since midnight
void UpdateDisplay(uint32_t time)
{
    // The LEDs on PORTA indicate the minutes
    PORTA = (time % 3600) / 60;

    // The LEDs on PORTB indicate the hours
    PORTB = time / 3600;

    // PORTC[0] blinks every second
    PORTC = time % 2;
}

// Function to modify time according to the state of the buttons
// I/O input: push buttons
// time: time to be displayed in seconds since midnight
// return value: the new time
uint32_t SetTime(uint32_t time)
{
    uint32_t newtime = time;

    if ((PIND & 0b0100) == 0)
    {
        // the minute button is pressed
        newtime = time + 60;
    }
    else if ((PIND & 0b1000) == 0)
    {
        // the hour button is pressed
        newtime = time + 3600;
    }
    else
    {
        // none of the buttons are pressed
        newtime = time;
    }

    return newtime;
}
