#include "../Headers/timer.h"

#include <avr/io.h>

//////////////////////////////////// Functions

// Function to initialize the timer peripheral
void SetupTimer(void)
{
    // 1. Timer input settings of TOSC1-2 pins
    ASSR |= (1 << AS2);

    // 2. Timer mode setting: Clear Timer on Compare Match (WGM2[1:0] = 0b10)
    TCCR2 |= (1 << WGM21);
    // the value of WGM20 is 0, there is no need to set

    // 3. Setting the maximal value of Timer
    // See Diagram 17-11. for more details (Timer/Counter2 Timing Diagram, CTC mode, with prescaler)
    // and the formula in chapter 17.7.2. (Timer2 CTC mode).
    OCR2 = 31;

    // 4. Prescaler setting: clk_TS2 / 1024 (CS2[2:0] = 0b111)
    // (This starts the counting in Timer2 as well, which was stopped so far.)
    TCCR2 |= (1 << CS22) | (1 << CS21) | (1 << CS20);
}

// The return value of this function shows whether a second has elapsed in the timer peripheral
// false: it hasn't elapsed
// true: one second has elapsed
bool CheckIfSecondElapsed(void)
{
    bool second_elapsed_b;

    if (0 != (TIFR & (1 << OCF2)))
    {
        // Resetting OCF2 bit
        TIFR = (1 << OCF2);

        second_elapsed_b = true;
    }
    else
    {
        second_elapsed_b = false;
    }

    return (second_elapsed_b);
}
